﻿<?php
///////////////////////////////////////////////////////////////////////////

require_once 'lib/hashed_array.php';
require_once 'lib/tv/abstract_tv.php';
require_once 'lib/tv/default_epg_item.php';

require_once 'mobitv_channel.php';
require_once 'mobitv_config.php';

///////////////////////////////////////////////////////////////////////////

class DemoTv extends AbstractTv
{
    public function __construct()
    {
        parent::__construct(
            AbstractTv::MODE_CHANNELS_N_TO_M,
            DemoConfig::TV_FAVORITES_SUPPORTED,
            true);
    }

    public function get_fav_icon_url()
    {
        return DemoConfig::FAV_CHANNEL_GROUP_ICON_PATH;
    }

    public function get_list_channel()
    {
        if ($load_sex == 'yes')
        $list = DemoConfig::CHANNEL_LIST_URL1;
        else if ($load_sex == 'no')
        $list =  DemoConfig::CHANNEL_LIST_URL2;
    }

    ///////////////////////////////////////////////////////////////////////
    ///////////////////////////////////////////////////////////////////////

    protected function load_channels(&$plugin_cookies)
    {
       $doc = file_get_contents(DemoConfig::CHANNEL_LIST_URL, true);
     
        if (is_null($doc))
            throw new Exception('Can not fetch playlist');
     
        $xml = simplexml_load_string($doc);

        if ($xml === false)
        {
            hd_print("Error: can not parse XML document.");
            hd_print("XML-text: $doc.");
            throw new Exception('Illegal XML document');
        }

        if ($xml->getName() !== 'tv_info')
        {
            hd_print("Error: unexpected node '" . $xml->getName() . "'. Expected: 'tv_info'");
            throw new Exception('Invalid XML document');
        }

        $this->channels = new HashedArray();
        $this->groups = new HashedArray();

        if ($this->is_favorites_supported())
        {
            $this->groups->put(
                new FavoritesGroup(
                    $this,
                    '__favorites',
                    DemoConfig::FAV_CHANNEL_GROUP_CAPTION,
                    DemoConfig::FAV_CHANNEL_GROUP_ICON_PATH));
        }

        $this->groups->put(
            new AllChannelsGroup(
                $this,
                DemoConfig::ALL_CHANNEL_GROUP_CAPTION,
                DemoConfig::ALL_CHANNEL_GROUP_ICON_PATH));

	$channels_id_parsed = array();
	try {
		$doc = HD::http_get_document(DemoConfig::M3U_ID_FILE_URL);
	}
	catch (Exception $e) {
		hd_print("Can't fetch myiptv_chennels_id, local copy used.");		
		$doc = file_get_contents(dirname(__FILE__).'/data/myiptv_channels_id');
	}
    	$channels_id_parsed = unserialize($doc);

        foreach ($xml->tv_categories->children() as $xml_tv_category)
        {
            if ($xml_tv_category->getName() !== 'tv_category')
            {
                hd_print("Error: unexpected node '" . $xml_tv_category->getName() .
                    "'. Expected: 'tv_category'");
                throw new Exception('Invalid XML document');
            }

            $this->groups->put(
                new DefaultGroup(
                    strval($xml_tv_category->id),
                    strval($xml_tv_category->caption),
                    strval($xml_tv_category->icon_url)));
        }
        $i = 0;
        $gid = 0;
        foreach ($xml->tv_channels->children() as $xml_tv_channel)
        {
            if ($xml_tv_channel->getName() !== 'tv_channel')
            {
                hd_print("Error: unexpected node '" . $xml_tv_channel->getName() .
                    "'. Expected: 'tv_channel'");
                throw new Exception('Invalid XML document');
            }

            $id_key = md5(strtolower(str_replace(array("\r", "\n", "\"", " "), '', $xml_tv_channel->caption)));
            $id = array_key_exists($id_key,$channels_id_parsed) ? $channels_id_parsed[$id_key] : 1000 + $i;
	    $cid = $gid."_".$id;
	    $i++;
            $channel =
                new DemoChannel(
                    strval($cid),
                    strval($xml_tv_channel->caption),
                    strval($xml_tv_channel->icon_url),
                    strval($xml_tv_channel->streaming_url),
                    intval($xml_tv_channel->number),
                    intval($xml_tv_channel->num_past_epg_days),
                    intval($xml_tv_channel->num_future_epg_days),
                    intval($xml_tv_channel->protected));

            $this->channels->put($channel);

            foreach ($xml_tv_channel->tv_categories->children() as $xml_tv_cat_id)
            {
                if ($xml_tv_cat_id->getName() !== 'tv_category_id')
                {
                    hd_print("Error: unexpected node '" . $xml_tv_cat_id->getName() .
                        "'. Expected: 'tv_category_id'");
                    throw new Exception('Invalid XML document');
                }

                $tv_category_id = intval($xml_tv_cat_id);

                $group = $this->groups->get($tv_category_id);

                // Link group and channel.

                $channel->add_group($group);
                $group->add_channel($channel);
            }
        }
    }

    ///////////////////////////////////////////////////////////////////////////
    ///////////////////////////////////////////////////////////////////////////

     public function get_tv_playback_url($channel_id, $archive_ts, $protect_code, &$plugin_cookies)
    {
        $url = $this->get_channel($channel_id)->get_streaming_url();  
        $nado = $this->get_channel($channel_id)->is_protected();
        if ($nado)
        {
              if ($protect_code !=='6591')  $url='';  //Children protection code = 6591
        }
        return $url;
    }

    public function get_day_epg_iterator($channel_id, $day_start_ts, &$plugin_cookies)
    { 
    
    list($garb, $channel_id) = preg_split('/_/', $channel_id);

    if ($channel_id >= 1000) 
	return array();
    
    $epg_shift = isset($plugin_cookies->epg_shift) ? $plugin_cookies->epg_shift : '0';

    $epg_date = date("Y-m-d", $day_start_ts);
    $epg = array();

    if (file_exists("/tmp/channel_".$channel_id."_".$day_start_ts)) {
	$doc = file_get_contents("/tmp/channel_".$channel_id."_".$day_start_ts);
	$epg = unserialize($doc);
    }
    else {
	try {
            $doc = HD::http_get_document(sprintf(DemoConfig::EPG_URL_FORMAT, $channel_id, $epg_date));
	}
	catch (Exception $e) {
	    hd_print("Can't fetch EPG ID:$id DATE:$epg_date");
	    return array();
	}
	
        $doc = iconv('WINDOWS-1251', 'UTF-8', $doc);

	$patterns = array("/<div class=\"desc\">/", "/<div class=\"onair\">/", "/<div class=\"pasttime\">/", "/<div class=\"time\">/", "/<br><br>/", "/<br>/", "/&nbsp;/");
        $replace = array("|", "\n", "\n", "\n", ". ", ". ", "");

	$doc = strip_tags(preg_replace($patterns, $replace, $doc));

        preg_match_all("/([0-2][0-9]:[0-5][0-9])([^\n]+)\n/", $doc, $matches);

	$last_time = 0;
	
        foreach ($matches[1] as $key => $time) {
	    $str = preg_split("/\|/", $matches[2][$key], 2);
	    $name = $str[0];
	    $desc = array_key_exists(1, $str) ? $str[1] : "";
	    $u_time = strtotime("$epg_date $time EEST");
	    $last_time = ($u_time < $last_time) ? $u_time + 86400  : $u_time ;
	    $epg[$last_time]["name"] = $name;
	    $epg[$last_time]["desc"] = $desc;
	    }
	file_put_contents("/tmp/channel_".$channel_id."_".$day_start_ts, serialize($epg));
	}
	$epg_result = array();

	ksort($epg, SORT_NUMERIC);

	foreach ($epg as $time => $value) {
	    $epg_result[] =
                new DefaultEpgItem(
                    strval($value["name"]),
                    strval($value["desc"]),
                    intval($time + $epg_shift),
                    intval(-1));
	}
	
	return
            new EpgIterator(
                $epg_result,
                $day_start_ts,
                $day_start_ts + 100400);
    }
}

///////////////////////////////////////////////////////////////////////////
?>
